==> haskell-mysql-simple-0.4.9-146.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-BU7LzITWgGEJpLINzcTJih
key:                  mysql-simple-0.4.9-BU7LzITWgGEJpLINzcTJih
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  f938e0464aded964b63c793aed64f0e2
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-BU7LzITWgGEJpLINzcTJih
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-IYNrdn8zmc85a8mxVRVIHo
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    pcre-light-0.4.1.3-8CTkJ27jmeB1Fwh42ZgVNy text-2.0.2 time-1.12.2
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-simple-0.4.9-147-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-3dH5LUT1bbL1CCWzXZiNlV
key:                  mysql-simple-0.4.9-3dH5LUT1bbL1CCWzXZiNlV
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  10b57c86c8877bbc8e0499ec171af732
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-3dH5LUT1bbL1CCWzXZiNlV
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-7hwMuxCIs5qHLFpGGyaXU4
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    pcre-light-0.4.1.3-LJnGRx9YMSlIeQnqxNBHah text-2.0.2 time-1.12.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
